@@ -26,9 +26,7 @@ class Aliases:
 
         _command = command.strip()
 
-        if(_command in self.repl.globals or
-           _command in self.repl.locals):
-
+        if _command in self.repl.globals:
             return command
 
         # resolve aliases
@@ -36,7 +34,7 @@ class Aliases:
             if not command.startswith(name):
                 continue
 
-            if(len(command) >= len(name) and
+            if(len(command) > len(name) and
                command[len(name)] in (' ', '\n', '\t')):
 
                 return '{}{}'.format(value, command[len(name):])
